@@ -32,7 +32,7 @@ class ASTROMER:
                  no_train=True,
                  maxlen=100,
                  batch_size=None,
-                 pretrained_weights=False,
+                 pretrained_weights=None,
                  finetuning = None,
                  overwrite=False):
         self.num_layers=num_layers
@@ -48,9 +48,9 @@ class ASTROMER:
         self.pretrained_weights=pretrained_weights
         self.overwrite_weights=overwrite
         
-        self.git_link="https://github.com/HarshVardhanGoyal/test_model.git"
+        self.git_link="https://github.com/vishnu701/test_model_weights.git"
         self.model_path = os.path.join(os.getcwd(),"weights")
-        self.model_name = "astromer_10022021"
+        self.model_name = pretrained_weights
 
         # Getting the desired model_name
         if finetuning in [None, "ogle", "alcock", "ogle_100"]:
@@ -58,8 +58,10 @@ class ASTROMER:
         else:
             raise ValueError("Specified fine-tuned model does not exist")
         
-        if self.pretrained_weights:
+        if self.pretrained_weights in ['macho']:
             self.load_configuration()
+        else:
+            raise ValueError("Specified pretrained model does not exist")
 
         serie  = Input(shape=(self.maxlen, 1),
                     batch_size=None,
@@ -99,7 +101,7 @@ class ASTROMER:
                     outputs=x,
                     name="ASTROMER")
 
-        if self.pretrained_weights:
+        if self.pretrained_weights is not None:
             # Loading the model weights
             try:
                 if self.finetuning is not None:
@@ -272,8 +274,7 @@ class ASTROMER:
             valid_mse.reset_states()
 
     def predict(self,
-                dataset,
-                predic_proba=False):
+                dataset):
 
         total_mse, inputs, reconstructions = [], [], []
         masks, times = [], []
